Class: Pescheck::AuthenticationApi
- Inherits:
-
Object
- Object
- Pescheck::AuthenticationApi
- Defined in:
- lib/pescheck/api/authentication_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#generate_jwt_token2(jwt_generation, opts = {}) ⇒ JWTResponse
Log in with email + password.
-
#generate_jwt_token2_with_http_info(jwt_generation, opts = {}) ⇒ Array<(JWTResponse, Integer, Hash)>
Log in with email + password.
-
#initialize(api_client = ApiClient.default) ⇒ AuthenticationApi
constructor
A new instance of AuthenticationApi.
-
#jwt_create(custom_token_obtain_pair, opts = {}) ⇒ CustomTokenObtainPair
Log in with email + password.
-
#jwt_create_with_http_info(custom_token_obtain_pair, opts = {}) ⇒ Array<(CustomTokenObtainPair, Integer, Hash)>
Log in with email + password.
-
#jwt_refresh_create(token_refresh, opts = {}) ⇒ TokenRefresh
Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.
-
#jwt_refresh_create_with_http_info(token_refresh, opts = {}) ⇒ Array<(TokenRefresh, Integer, Hash)>
Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthenticationApi
Returns a new instance of AuthenticationApi.
19 20 21 |
# File 'lib/pescheck/api/authentication_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pescheck/api/authentication_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#generate_jwt_token2(jwt_generation, opts = {}) ⇒ JWTResponse
Log in with email + password. Returns a JWT pair scoped to the organization or division specified by organisation_id/division_id (defaults to your current org). For a plain login, use POST /api/jwt/.
26 27 28 29 |
# File 'lib/pescheck/api/authentication_api.rb', line 26 def generate_jwt_token2(jwt_generation, opts = {}) data, _status_code, _headers = generate_jwt_token2_with_http_info(jwt_generation, opts) data end |
#generate_jwt_token2_with_http_info(jwt_generation, opts = {}) ⇒ Array<(JWTResponse, Integer, Hash)>
Log in with email + password. Returns a JWT pair scoped to the organization or division specified by organisation_id/division_id (defaults to your current org). For a plain login, use POST /api/jwt/.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pescheck/api/authentication_api.rb', line 35 def generate_jwt_token2_with_http_info(jwt_generation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthenticationApi.generate_jwt_token2 ...' end # verify the required parameter 'jwt_generation' is set if @api_client.config.client_side_validation && jwt_generation.nil? fail ArgumentError, "Missing the required parameter 'jwt_generation' when calling AuthenticationApi.generate_jwt_token2" end # resource path local_var_path = '/api/v2/jwt/generate/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(jwt_generation) # return_type return_type = opts[:debug_return_type] || 'JWTResponse' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"AuthenticationApi.generate_jwt_token2", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthenticationApi#generate_jwt_token2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#jwt_create(custom_token_obtain_pair, opts = {}) ⇒ CustomTokenObtainPair
Log in with email + password. Returns a JWT pair scoped to your current organization (last viewed, or first available). For a token scoped to a specific org or division, use POST /api/v2/jwt/generate/.
92 93 94 95 |
# File 'lib/pescheck/api/authentication_api.rb', line 92 def jwt_create(custom_token_obtain_pair, opts = {}) data, _status_code, _headers = jwt_create_with_http_info(custom_token_obtain_pair, opts) data end |
#jwt_create_with_http_info(custom_token_obtain_pair, opts = {}) ⇒ Array<(CustomTokenObtainPair, Integer, Hash)>
Log in with email + password. Returns a JWT pair scoped to your current organization (last viewed, or first available). For a token scoped to a specific org or division, use POST /api/v2/jwt/generate/.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pescheck/api/authentication_api.rb', line 101 def jwt_create_with_http_info(custom_token_obtain_pair, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthenticationApi.jwt_create ...' end # verify the required parameter 'custom_token_obtain_pair' is set if @api_client.config.client_side_validation && custom_token_obtain_pair.nil? fail ArgumentError, "Missing the required parameter 'custom_token_obtain_pair' when calling AuthenticationApi.jwt_create" end # resource path local_var_path = '/api/jwt/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(custom_token_obtain_pair) # return_type return_type = opts[:debug_return_type] || 'CustomTokenObtainPair' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"AuthenticationApi.jwt_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthenticationApi#jwt_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#jwt_refresh_create(token_refresh, opts = {}) ⇒ TokenRefresh
Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.
158 159 160 161 |
# File 'lib/pescheck/api/authentication_api.rb', line 158 def jwt_refresh_create(token_refresh, opts = {}) data, _status_code, _headers = jwt_refresh_create_with_http_info(token_refresh, opts) data end |
#jwt_refresh_create_with_http_info(token_refresh, opts = {}) ⇒ Array<(TokenRefresh, Integer, Hash)>
Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/pescheck/api/authentication_api.rb', line 167 def jwt_refresh_create_with_http_info(token_refresh, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthenticationApi.jwt_refresh_create ...' end # verify the required parameter 'token_refresh' is set if @api_client.config.client_side_validation && token_refresh.nil? fail ArgumentError, "Missing the required parameter 'token_refresh' when calling AuthenticationApi.jwt_refresh_create" end # resource path local_var_path = '/api/jwt/refresh/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(token_refresh) # return_type return_type = opts[:debug_return_type] || 'TokenRefresh' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"AuthenticationApi.jwt_refresh_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthenticationApi#jwt_refresh_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |