Class: Pescheck::ChecksApi
- Inherits:
-
Object
- Object
- Pescheck::ChecksApi
- Defined in:
- lib/pescheck/api/checks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ChecksApi
constructor
A new instance of ChecksApi.
-
#v2_checks_list(opts = {}) ⇒ Array<V2CheckInfo>
List the check types this API supports.
-
#v2_checks_list_with_http_info(opts = {}) ⇒ Array<(Array<V2CheckInfo>, Integer, Hash)>
List the check types this API supports.
- #v2_checks_retrieve(check_type, opts = {}) ⇒ V2CheckInfo
-
#v2_checks_retrieve_with_http_info(check_type, opts = {}) ⇒ Array<(V2CheckInfo, Integer, Hash)>
V2CheckInfo data, response status code and response headers.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pescheck/api/checks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v2_checks_list(opts = {}) ⇒ Array<V2CheckInfo>
List the check types this API supports. The list is bounded metadata about the available check types (not a paginated collection), so the response is a flat array.
26 27 28 29 |
# File 'lib/pescheck/api/checks_api.rb', line 26 def v2_checks_list(opts = {}) data, _status_code, _headers = v2_checks_list_with_http_info(opts) data end |
#v2_checks_list_with_http_info(opts = {}) ⇒ Array<(Array<V2CheckInfo>, Integer, Hash)>
List the check types this API supports. The list is bounded metadata about the available check types (not a paginated collection), so the response is a flat array.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pescheck/api/checks_api.rb', line 35 def v2_checks_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChecksApi.v2_checks_list ...' end # resource path local_var_path = '/api/v2/checks/' # query parameters query_params = opts[:query_params] || {} query_params[:'check_type'] = opts[:'check_type'] if !opts[:'check_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<V2CheckInfo>' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ChecksApi.v2_checks_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChecksApi#v2_checks_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v2_checks_retrieve(check_type, opts = {}) ⇒ V2CheckInfo
83 84 85 86 |
# File 'lib/pescheck/api/checks_api.rb', line 83 def v2_checks_retrieve(check_type, opts = {}) data, _status_code, _headers = v2_checks_retrieve_with_http_info(check_type, opts) data end |
#v2_checks_retrieve_with_http_info(check_type, opts = {}) ⇒ Array<(V2CheckInfo, Integer, Hash)>
Returns V2CheckInfo data, response status code and response headers.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/pescheck/api/checks_api.rb', line 91 def v2_checks_retrieve_with_http_info(check_type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChecksApi.v2_checks_retrieve ...' end # verify the required parameter 'check_type' is set if @api_client.config.client_side_validation && check_type.nil? fail ArgumentError, "Missing the required parameter 'check_type' when calling ChecksApi.v2_checks_retrieve" end pattern = Regexp.new(/^[a-z0-9]+$/) if @api_client.config.client_side_validation && check_type !~ pattern fail ArgumentError, "invalid value for 'check_type' when calling ChecksApi.v2_checks_retrieve, must conform to the pattern #{pattern}." end # resource path local_var_path = '/api/v2/checks/{check_type}/'.sub('{check_type}', CGI.escape(check_type.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V2CheckInfo' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ChecksApi.v2_checks_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChecksApi#v2_checks_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |