Class: Pescheck::DivisionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pescheck/api/divisions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DivisionsApi

Returns a new instance of DivisionsApi.



19
20
21
# File 'lib/pescheck/api/divisions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pescheck/api/divisions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#v2_organisations_divisions_create(division_write, opts = {}) ⇒ DivisionWrite

Create a division (a child organisation under the current parent org). Divisions are an advanced, rarely-needed feature: create one ONLY when the user has clearly stated they want to manage a separate business unit, location, or legal entity under their account. Do NOT create a division just to organise screenings, for a single-person or single-member organisation, or without an explicit request to do so. When in doubt, ask the user to confirm before calling this tool.

Parameters:

  • division_write (DivisionWrite)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/pescheck/api/divisions_api.rb', line 26

def v2_organisations_divisions_create(division_write, opts = {})
  data, _status_code, _headers = v2_organisations_divisions_create_with_http_info(division_write, opts)
  data
end

#v2_organisations_divisions_create_with_http_info(division_write, opts = {}) ⇒ Array<(DivisionWrite, Integer, Hash)>

Create a division (a child organisation under the current parent org). Divisions are an advanced, rarely-needed feature: create one ONLY when the user has clearly stated they want to manage a separate business unit, location, or legal entity under their account. Do NOT create a division just to organise screenings, for a single-person or single-member organisation, or without an explicit request to do so. When in doubt, ask the user to confirm before calling this tool.

Parameters:

  • division_write (DivisionWrite)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DivisionWrite, Integer, Hash)>)

    DivisionWrite data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pescheck/api/divisions_api.rb', line 35

def v2_organisations_divisions_create_with_http_info(division_write, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DivisionsApi.v2_organisations_divisions_create ...'
  end
  # verify the required parameter 'division_write' is set
  if @api_client.config.client_side_validation && division_write.nil?
    fail ArgumentError, "Missing the required parameter 'division_write' when calling DivisionsApi.v2_organisations_divisions_create"
  end
  # resource path
  local_var_path = '/api/v2/organisations/divisions/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(division_write)

  # return_type
  return_type = opts[:debug_return_type] || 'DivisionWrite'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"DivisionsApi.v2_organisations_divisions_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DivisionsApi#v2_organisations_divisions_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_organisations_divisions_list(opts = {}) ⇒ PaginatedDivisionReadOnlyList

List method that handles both paginated and unpaginated responses and enforces the max_total_records limit (500).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    A page number within the paginated result set. (default to 1)

  • :page_size (Integer)

    Number of results to return per page. (default to 50)

  • :paginate (Boolean)

    Enable/disable pagination. When false, max 500 records returned. (default to true)

Returns:



94
95
96
97
# File 'lib/pescheck/api/divisions_api.rb', line 94

def v2_organisations_divisions_list(opts = {})
  data, _status_code, _headers = v2_organisations_divisions_list_with_http_info(opts)
  data
end

#v2_organisations_divisions_list_with_http_info(opts = {}) ⇒ Array<(PaginatedDivisionReadOnlyList, Integer, Hash)>

List method that handles both paginated and unpaginated responses and enforces the max_total_records limit (500).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    A page number within the paginated result set. (default to 1)

  • :page_size (Integer)

    Number of results to return per page. (default to 50)

  • :paginate (Boolean)

    Enable/disable pagination. When false, max 500 records returned. (default to true)

Returns:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/pescheck/api/divisions_api.rb', line 105

def v2_organisations_divisions_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DivisionsApi.v2_organisations_divisions_list ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling DivisionsApi.v2_organisations_divisions_list, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling DivisionsApi.v2_organisations_divisions_list, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling DivisionsApi.v2_organisations_divisions_list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/v2/organisations/divisions/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'paginate'] = opts[:'paginate'] if !opts[:'paginate'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedDivisionReadOnlyList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"DivisionsApi.v2_organisations_divisions_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DivisionsApi#v2_organisations_divisions_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_organisations_divisions_partial_update(id, opts = {}) ⇒ DivisionWrite

A division is a child organisation under a parent org, used only when a customer needs to manage genuinely separate business units, locations, or legal entities under one account. The vast majority of organisations operate as a single entity and need no divisions. Only top-level (parent) organisations can have divisions.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



169
170
171
172
# File 'lib/pescheck/api/divisions_api.rb', line 169

def v2_organisations_divisions_partial_update(id, opts = {})
  data, _status_code, _headers = v2_organisations_divisions_partial_update_with_http_info(id, opts)
  data
end

#v2_organisations_divisions_partial_update_with_http_info(id, opts = {}) ⇒ Array<(DivisionWrite, Integer, Hash)>

A division is a child organisation under a parent org, used only when a customer needs to manage genuinely separate business units, locations, or legal entities under one account. The vast majority of organisations operate as a single entity and need no divisions. Only top-level (parent) organisations can have divisions.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(DivisionWrite, Integer, Hash)>)

    DivisionWrite data, response status code and response headers



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/pescheck/api/divisions_api.rb', line 179

def v2_organisations_divisions_partial_update_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DivisionsApi.v2_organisations_divisions_partial_update ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DivisionsApi.v2_organisations_divisions_partial_update"
  end
  # resource path
  local_var_path = '/api/v2/organisations/divisions/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_division_write'])

  # return_type
  return_type = opts[:debug_return_type] || 'DivisionWrite'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"DivisionsApi.v2_organisations_divisions_partial_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DivisionsApi#v2_organisations_divisions_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_organisations_divisions_retrieve(id, opts = {}) ⇒ DivisionReadOnly

A division is a child organisation under a parent org, used only when a customer needs to manage genuinely separate business units, locations, or legal entities under one account. The vast majority of organisations operate as a single entity and need no divisions. Only top-level (parent) organisations can have divisions.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



236
237
238
239
# File 'lib/pescheck/api/divisions_api.rb', line 236

def v2_organisations_divisions_retrieve(id, opts = {})
  data, _status_code, _headers = v2_organisations_divisions_retrieve_with_http_info(id, opts)
  data
end

#v2_organisations_divisions_retrieve_with_http_info(id, opts = {}) ⇒ Array<(DivisionReadOnly, Integer, Hash)>

A division is a child organisation under a parent org, used only when a customer needs to manage genuinely separate business units, locations, or legal entities under one account. The vast majority of organisations operate as a single entity and need no divisions. Only top-level (parent) organisations can have divisions.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DivisionReadOnly, Integer, Hash)>)

    DivisionReadOnly data, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/pescheck/api/divisions_api.rb', line 245

def v2_organisations_divisions_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DivisionsApi.v2_organisations_divisions_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DivisionsApi.v2_organisations_divisions_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/organisations/divisions/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DivisionReadOnly'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"DivisionsApi.v2_organisations_divisions_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DivisionsApi#v2_organisations_divisions_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#v2_organisations_divisions_update(id, division_write, opts = {}) ⇒ DivisionWrite

Update an existing division's contact, billing, and address details. Override also triggers a webhook on successful PUT and PATCH requests.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • division_write (DivisionWrite)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



298
299
300
301
# File 'lib/pescheck/api/divisions_api.rb', line 298

def v2_organisations_divisions_update(id, division_write, opts = {})
  data, _status_code, _headers = v2_organisations_divisions_update_with_http_info(id, division_write, opts)
  data
end

#v2_organisations_divisions_update_with_http_info(id, division_write, opts = {}) ⇒ Array<(DivisionWrite, Integer, Hash)>

Update an existing division's contact, billing, and address details. Override also triggers a webhook on successful PUT and PATCH requests.

Parameters:

  • id (String)

    A UUID string identifying this organisation.

  • division_write (DivisionWrite)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DivisionWrite, Integer, Hash)>)

    DivisionWrite data, response status code and response headers



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/pescheck/api/divisions_api.rb', line 308

def v2_organisations_divisions_update_with_http_info(id, division_write, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DivisionsApi.v2_organisations_divisions_update ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DivisionsApi.v2_organisations_divisions_update"
  end
  # verify the required parameter 'division_write' is set
  if @api_client.config.client_side_validation && division_write.nil?
    fail ArgumentError, "Missing the required parameter 'division_write' when calling DivisionsApi.v2_organisations_divisions_update"
  end
  # resource path
  local_var_path = '/api/v2/organisations/divisions/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(division_write)

  # return_type
  return_type = opts[:debug_return_type] || 'DivisionWrite'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['oauth2']

  new_options = opts.merge(
    :operation => :"DivisionsApi.v2_organisations_divisions_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DivisionsApi#v2_organisations_divisions_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end