Class: Pescheck::PatchedDivisionWrite
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::PatchedDivisionWrite
- Defined in:
- lib/pescheck/models/patched_division_write.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#city ⇒ Object
Returns the value of attribute city.
-
#contact_email ⇒ Object
Returns the value of attribute contact_email.
-
#contact_name ⇒ Object
Returns the value of attribute contact_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#invoice_email ⇒ Object
Returns the value of attribute invoice_email.
-
#name ⇒ Object
Returns the value of attribute name.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#postal ⇒ Object
Returns the value of attribute postal.
-
#use_parent_on_billing ⇒ Object
Returns the value of attribute use_parent_on_billing.
-
#use_parent_on_email ⇒ Object
Returns the value of attribute use_parent_on_email.
-
#use_parent_on_report ⇒ Object
Returns the value of attribute use_parent_on_report.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedDivisionWrite
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedDivisionWrite
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/pescheck/models/patched_division_write.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::PatchedDivisionWrite` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::PatchedDivisionWrite`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'postal') self.postal = attributes[:'postal'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'contact_name') self.contact_name = attributes[:'contact_name'] end if attributes.key?(:'contact_email') self.contact_email = attributes[:'contact_email'] end if attributes.key?(:'invoice_email') self.invoice_email = attributes[:'invoice_email'] end if attributes.key?(:'use_parent_on_email') self.use_parent_on_email = attributes[:'use_parent_on_email'] end if attributes.key?(:'use_parent_on_billing') self.use_parent_on_billing = attributes[:'use_parent_on_billing'] end if attributes.key?(:'use_parent_on_report') self.use_parent_on_report = attributes[:'use_parent_on_report'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
24 25 26 |
# File 'lib/pescheck/models/patched_division_write.rb', line 24 def address @address end |
#city ⇒ Object
Returns the value of attribute city.
22 23 24 |
# File 'lib/pescheck/models/patched_division_write.rb', line 22 def city @city end |
#contact_email ⇒ Object
Returns the value of attribute contact_email.
32 33 34 |
# File 'lib/pescheck/models/patched_division_write.rb', line 32 def contact_email @contact_email end |
#contact_name ⇒ Object
Returns the value of attribute contact_name.
30 31 32 |
# File 'lib/pescheck/models/patched_division_write.rb', line 30 def contact_name @contact_name end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pescheck/models/patched_division_write.rb', line 18 def id @id end |
#invoice_email ⇒ Object
Returns the value of attribute invoice_email.
34 35 36 |
# File 'lib/pescheck/models/patched_division_write.rb', line 34 def invoice_email @invoice_email end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/pescheck/models/patched_division_write.rb', line 20 def name @name end |
#phone ⇒ Object
Returns the value of attribute phone.
28 29 30 |
# File 'lib/pescheck/models/patched_division_write.rb', line 28 def phone @phone end |
#postal ⇒ Object
Returns the value of attribute postal.
26 27 28 |
# File 'lib/pescheck/models/patched_division_write.rb', line 26 def postal @postal end |
#use_parent_on_billing ⇒ Object
Returns the value of attribute use_parent_on_billing.
38 39 40 |
# File 'lib/pescheck/models/patched_division_write.rb', line 38 def use_parent_on_billing @use_parent_on_billing end |
#use_parent_on_email ⇒ Object
Returns the value of attribute use_parent_on_email.
36 37 38 |
# File 'lib/pescheck/models/patched_division_write.rb', line 36 def use_parent_on_email @use_parent_on_email end |
#use_parent_on_report ⇒ Object
Returns the value of attribute use_parent_on_report.
40 41 42 |
# File 'lib/pescheck/models/patched_division_write.rb', line 40 def use_parent_on_report @use_parent_on_report end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/pescheck/models/patched_division_write.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/pescheck/models/patched_division_write.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/pescheck/models/patched_division_write.rb', line 43 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'city' => :'city', :'address' => :'address', :'postal' => :'postal', :'phone' => :'phone', :'contact_name' => :'contact_name', :'contact_email' => :'contact_email', :'invoice_email' => :'invoice_email', :'use_parent_on_email' => :'use_parent_on_email', :'use_parent_on_billing' => :'use_parent_on_billing', :'use_parent_on_report' => :'use_parent_on_report' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/pescheck/models/patched_division_write.rb', line 322 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/pescheck/models/patched_division_write.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pescheck/models/patched_division_write.rb', line 71 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'city' => :'String', :'address' => :'String', :'postal' => :'String', :'phone' => :'String', :'contact_name' => :'String', :'contact_email' => :'String', :'invoice_email' => :'String', :'use_parent_on_email' => :'Boolean', :'use_parent_on_billing' => :'Boolean', :'use_parent_on_report' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/pescheck/models/patched_division_write.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && city == o.city && address == o.address && postal == o.postal && phone == o.phone && contact_name == o.contact_name && contact_email == o.contact_email && invoice_email == o.invoice_email && use_parent_on_email == o.use_parent_on_email && use_parent_on_billing == o.use_parent_on_billing && use_parent_on_report == o.use_parent_on_report end |
#eql?(o) ⇒ Boolean
309 310 311 |
# File 'lib/pescheck/models/patched_division_write.rb', line 309 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
315 316 317 |
# File 'lib/pescheck/models/patched_division_write.rb', line 315 def hash [id, name, city, address, postal, phone, contact_name, contact_email, invoice_email, use_parent_on_email, use_parent_on_billing, use_parent_on_report].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/pescheck/models/patched_division_write.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if !@city.nil? && @city.to_s.length > 255 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 255.') end if !@address.nil? && @address.to_s.length > 255 invalid_properties.push('invalid value for "address", the character length must be smaller than or equal to 255.') end if !@postal.nil? && @postal.to_s.length > 20 invalid_properties.push('invalid value for "postal", the character length must be smaller than or equal to 20.') end if !@phone.nil? && @phone.to_s.length > 20 invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 20.') end if !@contact_name.nil? && @contact_name.to_s.length > 255 invalid_properties.push('invalid value for "contact_name", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/pescheck/models/patched_division_write.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/pescheck/models/patched_division_write.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 255 return false if !@city.nil? && @city.to_s.length > 255 return false if !@address.nil? && @address.to_s.length > 255 return false if !@postal.nil? && @postal.to_s.length > 20 return false if !@phone.nil? && @phone.to_s.length > 20 return false if !@contact_name.nil? && @contact_name.to_s.length > 255 true end |