Class: Pescheck::ScreeningsApi
- Inherits:
-
Object
- Object
- Pescheck::ScreeningsApi
- Defined in:
- lib/pescheck/api/screenings_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ScreeningsApi
constructor
A new instance of ScreeningsApi.
- #v2_screenings_create(v2_screening_create, opts = {}) ⇒ V2ScreeningDetail
-
#v2_screenings_create_with_http_info(v2_screening_create, opts = {}) ⇒ Array<(V2ScreeningDetail, Integer, Hash)>
V2ScreeningDetail data, response status code and response headers.
-
#v2_screenings_documents_list(id, opts = {}) ⇒ Array<V2Document>
Retrieve screening documents Documents attached to the screening's checks.
-
#v2_screenings_documents_list_with_http_info(id, opts = {}) ⇒ Array<(Array<V2Document>, Integer, Hash)>
Retrieve screening documents Documents attached to the screening's checks.
- #v2_screenings_list(opts = {}) ⇒ PaginatedV2ScreeningListItemList
-
#v2_screenings_list_with_http_info(opts = {}) ⇒ Array<(PaginatedV2ScreeningListItemList, Integer, Hash)>
PaginatedV2ScreeningListItemList data, response status code and response headers.
- #v2_screenings_retrieve(id, opts = {}) ⇒ V2ScreeningDetail
-
#v2_screenings_retrieve_with_http_info(id, opts = {}) ⇒ Array<(V2ScreeningDetail, Integer, Hash)>
V2ScreeningDetail data, response status code and response headers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ScreeningsApi
Returns a new instance of ScreeningsApi.
19 20 21 |
# File 'lib/pescheck/api/screenings_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pescheck/api/screenings_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v2_screenings_create(v2_screening_create, opts = {}) ⇒ V2ScreeningDetail
25 26 27 28 |
# File 'lib/pescheck/api/screenings_api.rb', line 25 def v2_screenings_create(v2_screening_create, opts = {}) data, _status_code, _headers = v2_screenings_create_with_http_info(v2_screening_create, opts) data end |
#v2_screenings_create_with_http_info(v2_screening_create, opts = {}) ⇒ Array<(V2ScreeningDetail, Integer, Hash)>
Returns V2ScreeningDetail data, response status code and response headers.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pescheck/api/screenings_api.rb', line 33 def v2_screenings_create_with_http_info(v2_screening_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ScreeningsApi.v2_screenings_create ...' end # verify the required parameter 'v2_screening_create' is set if @api_client.config.client_side_validation && v2_screening_create.nil? fail ArgumentError, "Missing the required parameter 'v2_screening_create' when calling ScreeningsApi.v2_screenings_create" end # resource path local_var_path = '/api/v2/screenings/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v2_screening_create) # return_type return_type = opts[:debug_return_type] || 'V2ScreeningDetail' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ScreeningsApi.v2_screenings_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ScreeningsApi#v2_screenings_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v2_screenings_documents_list(id, opts = {}) ⇒ Array<V2Document>
Retrieve screening documents
Documents attached to the screening's checks. Files are delivered inline as Base64 in content. Narrow the result with check_id or check_type.
93 94 95 96 |
# File 'lib/pescheck/api/screenings_api.rb', line 93 def v2_screenings_documents_list(id, opts = {}) data, _status_code, _headers = v2_screenings_documents_list_with_http_info(id, opts) data end |
#v2_screenings_documents_list_with_http_info(id, opts = {}) ⇒ Array<(Array<V2Document>, Integer, Hash)>
Retrieve screening documents Documents attached to the screening's checks. Files are delivered inline as Base64 in `content`. Narrow the result with `check_id` or `check_type`.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/pescheck/api/screenings_api.rb', line 105 def v2_screenings_documents_list_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ScreeningsApi.v2_screenings_documents_list ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ScreeningsApi.v2_screenings_documents_list" end # resource path local_var_path = '/api/v2/screenings/{id}/documents/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'check_id'] = opts[:'check_id'] if !opts[:'check_id'].nil? query_params[:'check_type'] = opts[:'check_type'] if !opts[:'check_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<V2Document>' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ScreeningsApi.v2_screenings_documents_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ScreeningsApi#v2_screenings_documents_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v2_screenings_list(opts = {}) ⇒ PaginatedV2ScreeningListItemList
160 161 162 163 |
# File 'lib/pescheck/api/screenings_api.rb', line 160 def v2_screenings_list(opts = {}) data, _status_code, _headers = v2_screenings_list_with_http_info(opts) data end |
#v2_screenings_list_with_http_info(opts = {}) ⇒ Array<(PaginatedV2ScreeningListItemList, Integer, Hash)>
Returns PaginatedV2ScreeningListItemList data, response status code and response headers.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/pescheck/api/screenings_api.rb', line 170 def v2_screenings_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ScreeningsApi.v2_screenings_list ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ScreeningsApi.v2_screenings_list, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ScreeningsApi.v2_screenings_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ScreeningsApi.v2_screenings_list, must be greater than or equal to 1.' end # resource path local_var_path = '/api/v2/screenings/' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'paginate'] = opts[:'paginate'] if !opts[:'paginate'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedV2ScreeningListItemList' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ScreeningsApi.v2_screenings_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ScreeningsApi#v2_screenings_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v2_screenings_retrieve(id, opts = {}) ⇒ V2ScreeningDetail
232 233 234 235 |
# File 'lib/pescheck/api/screenings_api.rb', line 232 def v2_screenings_retrieve(id, opts = {}) data, _status_code, _headers = v2_screenings_retrieve_with_http_info(id, opts) data end |
#v2_screenings_retrieve_with_http_info(id, opts = {}) ⇒ Array<(V2ScreeningDetail, Integer, Hash)>
Returns V2ScreeningDetail data, response status code and response headers.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pescheck/api/screenings_api.rb', line 240 def v2_screenings_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ScreeningsApi.v2_screenings_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ScreeningsApi.v2_screenings_retrieve" end # resource path local_var_path = '/api/v2/screenings/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V2ScreeningDetail' # auth_names auth_names = opts[:debug_auth_names] || ['oauth2'] = opts.merge( :operation => :"ScreeningsApi.v2_screenings_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ScreeningsApi#v2_screenings_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |