Class: Pescheck::V2ProfileCheckEntry

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck/models/v2_profile_check_entry.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V2ProfileCheckEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ProfileCheckEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ProfileCheckEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'check_type')
    self.check_type = attributes[:'check_type']
  else
    self.check_type = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  else
    self.display_name = nil
  end

  if attributes.key?(:'configured_price')
    self.configured_price = attributes[:'configured_price']
  else
    self.configured_price = nil
  end

  if attributes.key?(:'config')
    if (value = attributes[:'config']).is_a?(Hash)
      self.config = value
    end
  else
    self.config = nil
  end

  if attributes.key?(:'input_fields')
    if (value = attributes[:'input_fields']).is_a?(Array)
      self.input_fields = value
    end
  else
    self.input_fields = nil
  end

  if attributes.key?(:'is_system_managed')
    self.is_system_managed = attributes[:'is_system_managed']
  else
    self.is_system_managed = nil
  end
end

Instance Attribute Details

#check_typeObject

  • addresscheck - addresscheck * adversemediacheck - adversemediacheck * bigcheck - bigcheck * criminalrecordscheck - criminalrecordscheck * criminalrecordsuploadcheck - criminalrecordsuploadcheck * customintegritycheck - customintegritycheck * cvcheck - cvcheck * edrcheck - edrcheck * focumcheck - focumcheck * id2check - id2check * idcheck - idcheck * integritycheck - integritycheck * openhealthcarecheck - openhealthcarecheck * permissioncheck - permissioncheck * pescheckadversemediacheck - pescheckadversemediacheck * qualificationcheck - qualificationcheck * righttoworkcheck - righttoworkcheck * vogcheck - vogcheck * watchlist2check - watchlist2check * watchlistcheck - watchlistcheck * workreferencecheck - workreferencecheck * worldwidecreditcheck - worldwidecreditcheck


21
22
23
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 21

def check_type
  @check_type
end

#configObject

Returns the value of attribute config.



27
28
29
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 27

def config
  @config
end

#configured_priceObject

Returns the value of attribute configured_price.



25
26
27
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 25

def configured_price
  @configured_price
end

#display_nameObject

Returns the value of attribute display_name.



23
24
25
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 23

def display_name
  @display_name
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 18

def id
  @id
end

#input_fieldsObject

Returns the value of attribute input_fields.



29
30
31
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 29

def input_fields
  @input_fields
end

#is_system_managedObject

Returns the value of attribute is_system_managed.



31
32
33
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 31

def is_system_managed
  @is_system_managed
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 56

def self.attribute_map
  {
    :'id' => :'id',
    :'check_type' => :'check_type',
    :'display_name' => :'display_name',
    :'configured_price' => :'configured_price',
    :'config' => :'config',
    :'input_fields' => :'input_fields',
    :'is_system_managed' => :'is_system_managed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 79

def self.openapi_types
  {
    :'id' => :'String',
    :'check_type' => :'String',
    :'display_name' => :'String',
    :'configured_price' => :'V2Money',
    :'config' => :'Hash<String, Object>',
    :'input_fields' => :'Array<Object>',
    :'is_system_managed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      check_type == o.check_type &&
      display_name == o.display_name &&
      configured_price == o.configured_price &&
      config == o.config &&
      input_fields == o.input_fields &&
      is_system_managed == o.is_system_managed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 304

def hash
  [id, check_type, display_name, configured_price, config, input_fields, is_system_managed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @check_type.nil?
    invalid_properties.push('invalid value for "check_type", check_type cannot be nil.')
  end

  if @display_name.nil?
    invalid_properties.push('invalid value for "display_name", display_name cannot be nil.')
  end

  if @configured_price.nil?
    invalid_properties.push('invalid value for "configured_price", configured_price cannot be nil.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  if @input_fields.nil?
    invalid_properties.push('invalid value for "input_fields", input_fields cannot be nil.')
  end

  if @is_system_managed.nil?
    invalid_properties.push('invalid value for "is_system_managed", is_system_managed cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/pescheck/models/v2_profile_check_entry.rb', line 198

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @check_type.nil?
  check_type_validator = EnumAttributeValidator.new('String', ["addresscheck", "adversemediacheck", "bigcheck", "criminalrecordscheck", "criminalrecordsuploadcheck", "customintegritycheck", "cvcheck", "edrcheck", "focumcheck", "id2check", "idcheck", "integritycheck", "openhealthcarecheck", "permissioncheck", "pescheckadversemediacheck", "qualificationcheck", "righttoworkcheck", "vogcheck", "watchlist2check", "watchlistcheck", "workreferencecheck", "worldwidecreditcheck"])
  return false unless check_type_validator.valid?(@check_type)
  return false if @display_name.nil?
  return false if @configured_price.nil?
  return false if @config.nil?
  return false if @input_fields.nil?
  return false if @is_system_managed.nil?
  true
end