Class: Pescheck::V2ProfileUpdateCheck
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::V2ProfileUpdateCheck
- Defined in:
- lib/pescheck/models/v2_profile_update_check.rb
Overview
Profile update entry. Same shape as create plus optional profile_check_id for in-place update of an existing check. Absent profile_check_id = add new.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#check_type ⇒ Object
addresscheck- addresscheck *adversemediacheck- adversemediacheck *bigcheck- bigcheck *criminalrecordscheck- criminalrecordscheck *criminalrecordsuploadcheck- criminalrecordsuploadcheck *customintegritycheck- customintegritycheck *cvcheck- cvcheck *edrcheck- edrcheck *focumcheck- focumcheck *id2check- id2check *idcheck- idcheck *integritycheck- integritycheck *openhealthcarecheck- openhealthcarecheck *permissioncheck- permissioncheck *pescheckadversemediacheck- pescheckadversemediacheck *qualificationcheck- qualificationcheck *righttoworkcheck- righttoworkcheck *vogcheck- vogcheck *watchlist2check- watchlist2check *watchlistcheck- watchlistcheck *workreferencecheck- workreferencecheck *worldwidecreditcheck- worldwidecreditcheck.
-
#config ⇒ Object
Returns the value of attribute config.
-
#profile_check_id ⇒ Object
Returns the value of attribute profile_check_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V2ProfileUpdateCheck
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V2ProfileUpdateCheck
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ProfileUpdateCheck` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ProfileUpdateCheck`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'check_type') self.check_type = attributes[:'check_type'] else self.check_type = nil end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end end if attributes.key?(:'profile_check_id') self.profile_check_id = attributes[:'profile_check_id'] end end |
Instance Attribute Details
#check_type ⇒ Object
addresscheck- addresscheck *adversemediacheck- adversemediacheck *bigcheck- bigcheck *criminalrecordscheck- criminalrecordscheck *criminalrecordsuploadcheck- criminalrecordsuploadcheck *customintegritycheck- customintegritycheck *cvcheck- cvcheck *edrcheck- edrcheck *focumcheck- focumcheck *id2check- id2check *idcheck- idcheck *integritycheck- integritycheck *openhealthcarecheck- openhealthcarecheck *permissioncheck- permissioncheck *pescheckadversemediacheck- pescheckadversemediacheck *qualificationcheck- qualificationcheck *righttoworkcheck- righttoworkcheck *vogcheck- vogcheck *watchlist2check- watchlist2check *watchlistcheck- watchlistcheck *workreferencecheck- workreferencecheck *worldwidecreditcheck- worldwidecreditcheck
20 21 22 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 20 def check_type @check_type end |
#config ⇒ Object
Returns the value of attribute config.
22 23 24 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 22 def config @config end |
#profile_check_id ⇒ Object
Returns the value of attribute profile_check_id.
24 25 26 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 24 def profile_check_id @profile_check_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 49 def self.attribute_map { :'check_type' => :'check_type', :'config' => :'config', :'profile_check_id' => :'profile_check_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 68 def self.openapi_types { :'check_type' => :'String', :'config' => :'Hash<String, Object>', :'profile_check_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && check_type == o.check_type && config == o.config && profile_check_id == o.profile_check_id end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 165 def hash [check_type, config, profile_check_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @check_type.nil? invalid_properties.push('invalid value for "check_type", check_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 |
# File 'lib/pescheck/models/v2_profile_update_check.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @check_type.nil? check_type_validator = EnumAttributeValidator.new('String', ["addresscheck", "adversemediacheck", "bigcheck", "criminalrecordscheck", "criminalrecordsuploadcheck", "customintegritycheck", "cvcheck", "edrcheck", "focumcheck", "id2check", "idcheck", "integritycheck", "openhealthcarecheck", "permissioncheck", "pescheckadversemediacheck", "qualificationcheck", "righttoworkcheck", "vogcheck", "watchlist2check", "watchlistcheck", "workreferencecheck", "worldwidecreditcheck"]) return false unless check_type_validator.valid?(@check_type) true end |