Class: Pescheck::WebhookResponse

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck/models/webhook_response.rb

Overview

Serializer for webhook responses

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/pescheck/models/webhook_response.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::WebhookResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::WebhookResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'events')
    self.events = attributes[:'events']
  else
    self.events = nil
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  else
    self.verified = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'organisation_name')
    self.organisation_name = attributes[:'organisation_name']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#activeObject

Returns the value of attribute active.



27
28
29
# File 'lib/pescheck/models/webhook_response.rb', line 27

def active
  @active
end

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/pescheck/models/webhook_response.rb', line 35

def created_at
  @created_at
end

#eventsObject

Returns the value of attribute events.



25
26
27
# File 'lib/pescheck/models/webhook_response.rb', line 25

def events
  @events
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/pescheck/models/webhook_response.rb', line 19

def id
  @id
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/pescheck/models/webhook_response.rb', line 21

def name
  @name
end

#organisation_nameObject

Returns the value of attribute organisation_name.



33
34
35
# File 'lib/pescheck/models/webhook_response.rb', line 33

def organisation_name
  @organisation_name
end

#tokenObject

Returns the value of attribute token.



31
32
33
# File 'lib/pescheck/models/webhook_response.rb', line 31

def token
  @token
end

#updated_atObject

Returns the value of attribute updated_at.



37
38
39
# File 'lib/pescheck/models/webhook_response.rb', line 37

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



23
24
25
# File 'lib/pescheck/models/webhook_response.rb', line 23

def url
  @url
end

#verifiedObject

Returns the value of attribute verified.



29
30
31
# File 'lib/pescheck/models/webhook_response.rb', line 29

def verified
  @verified
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/pescheck/models/webhook_response.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/pescheck/models/webhook_response.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/pescheck/models/webhook_response.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'url' => :'url',
    :'events' => :'events',
    :'active' => :'active',
    :'verified' => :'verified',
    :'token' => :'token',
    :'organisation_name' => :'organisation_name',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/pescheck/models/webhook_response.rb', line 315

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
# File 'lib/pescheck/models/webhook_response.rb', line 82

def self.openapi_nullable
  Set.new([
    :'events',
    :'token',
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pescheck/models/webhook_response.rb', line 66

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'url' => :'String',
    :'events' => :'Object',
    :'active' => :'Boolean',
    :'verified' => :'Boolean',
    :'token' => :'String',
    :'organisation_name' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/pescheck/models/webhook_response.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      url == o.url &&
      events == o.events &&
      active == o.active &&
      verified == o.verified &&
      token == o.token &&
      organisation_name == o.organisation_name &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


302
303
304
# File 'lib/pescheck/models/webhook_response.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



308
309
310
# File 'lib/pescheck/models/webhook_response.rb', line 308

def hash
  [id, name, url, events, active, verified, token, organisation_name, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/pescheck/models/webhook_response.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 200
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 200.')
  end

  if @verified.nil?
    invalid_properties.push('invalid value for "verified", verified cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/pescheck/models/webhook_response.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/pescheck/models/webhook_response.rb', line 202

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @url.nil?
  return false if @url.to_s.length > 200
  return false if @verified.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end